==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/breves/lang/breves_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/breves?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'breve' => 'Nieuwsbericht',
	'breves' => 'Nieuwsberichten',

	// E
	'entree_breve_publiee' => 'Dit bericht is:',
	'entree_texte_breve' => 'Tekst van het bericht',

	// I
	'icone_breves' => 'Berichten',
	'icone_ecrire_nouvel_article' => 'De berichten van deze rubriek',
	'icone_modifier_breve' => 'Dit bericht wijzigen',
	'icone_nouvelle_breve' => 'Een nieuwsbericht schrijven',
	'info_1_breve' => '1 bericht',
	'info_aucun_breve' => 'Geen nieuws',
	'info_breves' => 'Werkt je website met het systeem van berichten?',
	'info_breves_02' => 'nieuwsberichten',
	'info_breves_valider' => 'Berichten ter goedkeuring',
	'info_gauche_numero_breve' => 'Bericht nummer',
	'info_nb_breves' => '@nb@ berichten',
	'item_breve_proposee' => 'ter evaluatie voorgesteld',
	'item_breve_refusee' => 'geweigerd',
	'item_breve_validee' => 'goedgekeurd',
	'item_non_utiliser_breves' => 'Geen gebruik maken van nieuwsberichten',
	'item_utiliser_breves' => 'Nieuwsberichten gebruiken',

	// L
	'logo_breve' => 'Logo van het nieuwsbericht',

	// T
	'texte_breves' => 'Berichten zijn korte en eenvoudige teksten die je toelaten nieuws snel online te brengen, een persbericht op te stellen, een evenementenkalender te maken, ...',
	'titre_breve_proposee' => 'Voorgesteld bericht',
	'titre_breve_publiee' => 'Gepubliceerd bericht',
	'titre_breve_refusee' => 'Geweigerd bericht',
	'titre_breves' => 'Berichten',
	'titre_langue_breve' => 'Taal van het nieuwsbericht',
	'titre_nouvelle_breve' => 'Nieuwe nieuwsbericht',
	'titre_page_breves' => 'Berichten'
);

?>

==> spip_3.2.7.orig.tar.xz: spip/plugins-dist/breves/lang/breves_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/breves?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'breve' => 'Nieuwsbericht',
	'breves' => 'Nieuwsberichten',

	// E
	'entree_breve_publiee' => 'Dit bericht is:',
	'entree_texte_breve' => 'Tekst van het bericht',

	// I
	'icone_breves' => 'Berichten',
	'icone_ecrire_nouvel_article' => 'De berichten van deze rubriek',
	'icone_modifier_breve' => 'Dit bericht wijzigen',
	'icone_nouvelle_breve' => 'Een nieuwsbericht schrijven',
	'info_1_breve' => '1 bericht',
	'info_aucun_breve' => 'Geen nieuwsbericht',
	'info_breves' => 'Werkt je website met nieuwsberichten?',
	'info_breves_02' => 'nieuwsberichten',
	'info_breves_valider' => 'Berichten ter goedkeuring',
	'info_gauche_numero_breve' => 'Bericht nummer',
	'info_nb_breves' => '@nb@ berichten',
	'item_breve_proposee' => 'ter evaluatie',
	'item_breve_refusee' => 'geweigerd',
	'item_breve_validee' => 'goedgekeurd',
	'item_non_utiliser_breves' => 'Nieuwsberichten niet gebruiken',
	'item_utiliser_breves' => 'Nieuwsberichten gebruiken',

	// L
	'logo_breve' => 'Logo van het nieuwsbericht',

	// T
	'texte_breves' => 'Nieuwsberichten zijn korte en eenvoudige teksten die snel online geplaatst kunnen worden: een persbericht opstellen, een evenementenkalender maken, ...',
	'titre_breve_proposee' => 'Voorgesteld bericht',
	'titre_breve_publiee' => 'Gepubliceerd bericht',
	'titre_breve_refusee' => 'Geweigerd bericht',
	'titre_breves' => 'Berichten',
	'titre_langue_breve' => 'Taal van het nieuwsbericht',
	'titre_nouvelle_breve' => 'Nieuwe nieuwsbericht',
	'titre_page_breves' => 'Nieuwsberichten'
);
